%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|perl -pe 's/^(.*)-.*?$/$1/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*-(.*?)$/$1/g')}}

# Definitions for symvers files.
%define vmw_symvers_dir etc/vmware-tools/symvers
%define bld_symvers_file Module.symvers

Name:         vmware-tools-vmsync
BuildRequires: kernel-source kernel-syms gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmsync kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.1.0.1
Release:      1.sles11
Source1:      vmsync-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

Source0:      vmsync.tar
Source2:      vmsync-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*)-.*?$/$1/g')

# Make sure kernel-source is installed or the
# kernel_module_package macro will throw an error rather than a nice message
%{!?kernel_module_package: You must have the kernel-source package installed to build this package.}

%define vmware_use_symvers_file 1

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*-(.*)$/$1/g')}
%kernel_module_package -t %{SOURCE2} %{current_flavor}

%prep
%setup -n vmsync-only

%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-9.0.3.0-%{kernel_version}-$flavor

  rm -rf ../$flavor ../vmsync.o
  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor clean

  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vmsync" = "vsock" -o "vmsync" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from /usr/src/packages/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE %{bld_symvers_file}
  fi

  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor
  mkdir ../$flavor
  cp ../vmsync.o ../$flavor

  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vmsync_SYMVERS_FILE=%{vmw_symvers_dir}/vmsync-1.1.0.1-%{kernel_version}-$flavor
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vmsync.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}-$flavor/updates/vmsync.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vmsync_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmsync.  The vmsync kernel module provides functions used by VMware Tools to freeze I/O to mounted file systems and flush any in-memory data to disk, used when quiescing virtual machines.

%package common
Summary:      Contains the common files used by all the vmsync kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.11
Release:      1.sles11
Version:      8.6.11

%description common
 This package contains the common system configuration and scripts responsible for loading the vmsync kernel module.  The vmsync kernel module provides functions used by VMware Tools to freeze I/O to mounted file systems and flush any in-memory data to disk, used when quiescing virtual machines.

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmsync ]; then
      /sbin/insserv -r vmsync >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl --os=linux,sle,11 --kernel=%{kernel_version} --toDeconfigure=vmsync
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,sle,11 --dbDelAnswer VMSYNC_NAME
fi

# Configure
if [ -e /etc/init.d/vmsync ]; then
   /sbin/insserv -f vmsync >/dev/null 2>&1
fi
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,sle,11 --dbAddAnswer VMSYNC_NAME,vmsync
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-config.pl --os=linux,sle,11 --kernel=%{kernel_version} --toConfigure=vmsync

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmsync ]; then
      /sbin/insserv -r vmsync >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl --os=linux,sle,11 --kernel=%{kernel_version} --toDeconfigure=vmsync
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,sle,11 --dbDelAnswer VMSYNC_NAME
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-config.pl
/etc/init.d/vmsync
